add_mmc_block_device

Function add_mmc_block_device 

pub fn add_mmc_block_device(
    locked: &mut Locked<Unlocked>,
    current_task: &CurrentTask,
) -> Result<Arc<MmcBlockDevice>, Errno>
Adds an mmc block device at /dev/block/mmcblk0. The current implementation is just a stub that exports the typical sysfs layout for block devices, but cannot be read from or written to.