pub struct TaskInfo {
pub thread_group: Arc<ThreadGroup>,
pub memory_manager: Option<Arc<MemoryManager>>,
}Expand description
Result returned when creating new Zircon processes for tasks.
This does not include the task’s Zircon thread. Backing threads are attached later in the task
lifecycle, when creating an execution context in [execute_task()].
Fields
thread_group: Arc<ThreadGroup>The thread group that the task should be added to.
memory_manager: Option<Arc<MemoryManager>>The memory manager to use for the task.