pub type SyscallLoopEntry = fn(&mut CurrentTask) -> ExitStatus;Expand description
The type of function that must be provided by the kernel binary to enter the syscall loop.
pub type SyscallLoopEntry = fn(&mut CurrentTask) -> ExitStatus;The type of function that must be provided by the kernel binary to enter the syscall loop.