devtmpfs_create_device

Function devtmpfs_create_device 

pub fn devtmpfs_create_device(
    kernel: &Kernel,
    device_metadata: DeviceMetadata,
) -> Result<(), Errno>
Creates a device node in the devtmpfs filesystem.

This function executes the creation in a background thread and blocks the calling thread until the device node is fully created. This blocking behavior matches Linux.