pub struct NumberOfElementsRead(pub usize);Expand description
Holds the number of elements read by the callback to read_to_vec.
Used to make it clear to callers that the callback should return the number of elements read and not the number of bytes read.
Tuple Fields
0: usizeAuto Trait Implementations
impl Freeze for NumberOfElementsRead
impl RefUnwindSafe for NumberOfElementsRead
impl Send for NumberOfElementsRead
impl Sync for NumberOfElementsRead
impl Unpin for NumberOfElementsRead
impl UnsafeUnpin for NumberOfElementsRead
impl UnwindSafe for NumberOfElementsRead