pub struct LocklessRingBuffer { /* private fields */ }Implementations
Sourceimpl LocklessRingBuffer
impl LocklessRingBuffer
pub const PAGE_HEADER_SIZE: usize = 16
Sourcepub fn new(
size_bytes: usize,
overwrite: bool,
write_event_async_id: Id,
) -> Result<Self, Errno>
pub fn new( size_bytes: usize, overwrite: bool, write_event_async_id: Id, ) -> Result<Self, Errno>
Creates a new LocklessRingBuffer. size_bytes: Size of the ring buffer. Must be at least PAGE_SIZE * 3 and will be rounded up to a multiple of PAGE_SIZE. overwrite: If true, old pages will be dropped when the ring is full. If false, writes will fail until the data is read. write_event_async_id: The async trace event ID for write events.
pub fn dropped_pages(&self) -> u64
Sourceimpl LocklessRingBuffer
impl LocklessRingBuffer
pub fn reserve( &self, size: usize, ) -> Result<(Reservation<'_>, BootInstant, Duration<BootTimeline>), Errno>
pub fn commit(&self, reservation: Reservation<'_>)
pub fn swap_reader_page(&self) -> Option<usize>
pub fn read(&self, buf: &mut dyn OutputBuffer) -> Result<usize, Errno>
pub fn is_enabled(&self) -> bool
pub fn disable(&self) -> Result<u64, Errno>
pub fn enable(&self) -> Result<BootInstant, Errno>