OwnedMessageCounter

Struct OwnedMessageCounter 

pub struct OwnedMessageCounter { /* private fields */ }
Owns a zx::Counter to track pending messages that prevent the container from suspending.

This struct ensures that the counter is reset to 0 when the last strong reference is dropped, effectively releasing any wake lock held by this counter.

Implementations

Source

impl OwnedMessageCounter

pub fn new(name: &str, counter: Option<Counter>) -> OwnedMessageCounterHandle

pub fn mark_handled(&self)

Decrements the counter, signaling that a pending message or operation has been handled.

This should be called when the work associated with a previous mark_pending call is complete.

pub fn mark_pending(&self)

Increments the counter, signaling that a new message or operation is pending.

This prevents the system from suspending until a corresponding mark_handled call is made.

pub fn share( self: &OwnedMessageCounterHandle, new_pending_message: bool, ) -> SharedMessageCounter

Creates a SharedMessageCounter from this OwnedMessageCounter.

new_pending_message - if a new pending message should be added