pub struct WakeupSource {
pub last_actor: Option<TaskCommand>,
/* private fields */
}Expand description
Wake source persistent info, exposed in inspect diagnostics.
Fields
last_actor: Option<TaskCommand>The last task command that activated this wakeup source.
Implementations
Sourceimpl WakeupSource
impl WakeupSource
Sourcepub fn display_name(&self, origin: &WakeupSourceOrigin) -> String
pub fn display_name(&self, origin: &WakeupSourceOrigin) -> String
Lazily formats the display name for inspection and logging.
Sourcepub fn active_duration(&self) -> MonotonicDuration
pub fn active_duration(&self) -> MonotonicDuration
Returns the amount of time passed since this wake source was last recorded as active. For active wake sources, this is exactly the time since the source became active. For inactive sources it’s zero.