OnWakeOps

Trait OnWakeOps 

pub trait OnWakeOps: Send + Sync {
    // Required method
    fn on_wake(&self, current_task: &CurrentTask, baton_lease: &NullableHandle);
}
Called when a wake happens resulting from a timer going off.

Required Methods

fn on_wake(&self, current_task: &CurrentTask, baton_lease: &NullableHandle)

Called on wake events.

Must not block.

Args
  • current_task: the currently active task
  • baton_lease: the wake lease is provided if on_wake has critical work to do and needs to prevent suspend.

Implementors