pub fn bprm_committed_creds(current_task: &CurrentTask) -> Result<(), Errno>Expand description
Called immediately after new credentials have been applied to the process during exec().
Corresponds to the bprm_committed_creds() LSM hook.
pub fn bprm_committed_creds(current_task: &CurrentTask) -> Result<(), Errno>Called immediately after new credentials have been applied to the process during exec().
Corresponds to the bprm_committed_creds() LSM hook.