pub fn creds_start_internal_operation(
current_task: &CurrentTask,
) -> Arc<Credentials> ⓘExpand description
Marks the credentials as being used for an internal operation. All SELinux permission checks will be skipped on this task.
pub fn creds_start_internal_operation(
current_task: &CurrentTask,
) -> Arc<Credentials> ⓘMarks the credentials as being used for an internal operation. All SELinux permission checks will be skipped on this task.