pub fn file_system_resolve_security(
current_task: &CurrentTask,
file_system: &FileSystemHandle,
) -> Result<(), Errno>Expand description
Resolves the labeling scheme and arguments for the file_system, based on the loaded policy.
If no policy has yet been loaded then no work is done, and the file_system will instead be
labeled when a policy is first loaded.
If the file_system was already labeled then no further work is done.