pub fn fs_node_init_with_dentry(
current_task: &CurrentTask,
dir_entry: &DirEntryHandle,
) -> Result<(), Errno>Expand description
Called by the VFS to initialize the security state for an FsNode that is being linked at
dir_entry.
If the FsNode security state had already been initialized, or no policy is yet loaded, then
this is a no-op.
Corresponds to the d_instantiate() LSM hook.