force_signal

Function force_signal 

pub fn force_signal(
    current_task: &mut CurrentTask,
    siginfo: SignalInfo,
    restricted_exception: Option<ExceptionReport>,
)
Delivers a synchronous kernel signal (SignalInfo) immediately, unmasking it and resetting its disposition to SIG_DFL if it is currently blocked or SIG_IGN.

If restricted_exception is Some, the zx::ExceptionReport and task memory map are logged when the signal results in a core dump.