CurrentCreds

Enum CurrentCreds 

pub enum CurrentCreds {
    Cached(Arc<Credentials>),
    Overridden(Arc<Credentials>),
}
Represents the current state of the task’s subjective credentials.

Variants



Cached(Arc<Credentials>)

The task does not have overridden credentials, the subjective creds are identical to the objective creds stored in the Task. Since credentials are often accessed from the current task, we hold a reference here that does not necessitate going through the RCU machinery to read.



Overridden(Arc<Credentials>)

The task has overridden subjective credentials.