pub enum RunState {
Running,
Waiter(WaiterRef),
Event(Arc<InterruptibleEvent>),
Frozen(Waiter),
}Expand description
Whether, and how, this task is blocked. This enum can be extended with new variants to optimize different kinds of waiting.
Variants
Running
This task is not blocked.
The task might be running in userspace or kernel.
Waiter(WaiterRef)
This thread is blocked in a Waiter.
Event(Arc<InterruptibleEvent>)
This thread is blocked in an InterruptibleEvent.
Frozen(Waiter)
This thread is frozen by a Waiter.
When waiting on the Waiter, it should have a loop to prevent any signals except
notification.
Implementations