Idr

Struct Idr 

pub struct Idr<T: RcuDroppable + Send + Sync + 'static, L: LockLevel> { /* private fields */ }
A concurrent, lock-free radix tree mapped structure primarily employed to map 32-bit IDs to objects. Optimized for massively contended reads.

Implementations

Source

impl<T: RcuDroppable + Send + Sync + 'static, L: LockLevel> Idr<T, L>

pub fn new(alloc_mode: IdrAllocMode) -> Self

Creates a new Idr radix tree with the specified allocation mode.

pub fn new_cyclic(min_after_wrap: Option<u32>) -> Self

Creates a new cyclic Idr radix tree with an optional minimum ID after wrapping.

pub fn max(&self) -> u32

Returns the maximal value allowed for allocation in this Idr.

pub fn set_max(&self, max: u32)

Sets the maximal value allowed for allocation in this Idr.

pub fn lock(&self) -> IdrGuard<'_, T, L>

Acquires the writer lock, returning an IdrGuard that provides mutating operations.

pub fn lookup(&self, id: u32, scope: &RcuReadScope) -> Option<Arc<T>>

RCU protected lock-free lookup for readers

pub fn iter<'a>(&'a self, scope: &'a RcuReadScope) -> IdrIterator<'a, T> ⓘ

Returns a lock-free RCU iterator over all entries