IdrGuard

Struct IdrGuard 

pub struct IdrGuard<'a, T: RcuDroppable + Send + Sync + 'static, L: LockLevel> { /* private fields */ }
An RAII guard representing exclusive writer access to an Idr.

Holding this guard serializes mutations (allocations, reservations, removals) to the radix tree while allowing concurrent lock-free reads.

Implementations

Source

impl<'a, T: RcuDroppable + Send + Sync + 'static, L: LockLevel> IdrGuard<'a, T, L>

pub fn alloc<F>(&mut self, factory: F) -> Option<(u32, Arc<T>)>
where F: FnOnce(u32) -> Arc<T>,

Allocates the next available ID by calling a factory providing the newly acquired ID.

Depending on the Idr configuration, allocation will be either linear starting from 0, or cyclic starting from the previous cursor position.

pub fn reserve_id(&mut self, id: u32)

Marks a specific ID as unavailable so the allocator will never return it. Does not populate the tree with an item.

pub fn remove(&mut self, id: u32)

Removes an item by ID.

Methods from Deref<Target = Idr<T, L>>

pub fn max(&self) -> u32

Returns the maximal value allowed for allocation in this Idr.

pub fn set_max(&self, max: u32)

Sets the maximal value allowed for allocation in this Idr.

pub fn lock(&self) -> IdrGuard<'_, T, L>

Acquires the writer lock, returning an IdrGuard that provides mutating operations.

pub fn lookup(&self, id: u32, scope: &RcuReadScope) -> Option<Arc<T>>

RCU protected lock-free lookup for readers

pub fn iter<'a>(&'a self, scope: &'a RcuReadScope) -> IdrIterator<'a, T> ⓘ

Returns a lock-free RCU iterator over all entries