pub struct CgroupRoot {
pub hierarchy_id: u32,
pub controllers: BTreeSet<ControllerType>,
/* private fields */
}Expand description
CgroupRoot is the root of the cgroup hierarchy. The root cgroup is different from the rest of
the cgroups in a cgroup hierarchy (sub-cgroups of the root) in a few ways:
-
The root contains all known processes on cgroup creation, and all new processes as they are spawned. As such, the root cgroup reports processes belonging to it differently than its sub-cgroups.
-
The root does not contain resource controller interface files, as otherwise they would apply to the whole system.
-
The root does not own a
FsNodeas it is created and owned by theFileSysteminstead.
Fields
hierarchy_id: u32The ID of this hierarchy. 0 is reserved for cgroup v2.
controllers: BTreeSet<ControllerType>Controllers supported by this hierarchy.
Implementations
Sourceimpl CgroupRoot
impl CgroupRoot
pub fn new( hierarchy_id: u32, controllers: BTreeSet<ControllerType>, ) -> Arc<CgroupRoot> ⓘ
pub fn has_controller(&self, controller: ControllerType) -> bool
pub fn get_cgroup<TG: Copy + Into<ThreadGroupKey>>( &self, tg: TG, ) -> Option<Weak<Cgroup>>
pub fn get_cgroup_inspect(&self) -> Inspector