pub struct DeferredZombiePTracer {
pub tracer_pid: Pid,
pub tracee_tid: Pid,
pub tracee_pgid: Pid,
pub tracee_pid: Pid,
}Expand description
Child process that have exited, but the zombie ptrace needs to be consumed before they can be waited for.
Fields
tracer_pid: PidOriginal tracer
tracee_tid: PidTracee tid
tracee_pgid: PidTracee pgid
tracee_pid: PidTracee thread group