pub struct IpTables { /* private fields */ }Expand description
Stores [IpTable]s associated with each protocol.
Implementations
Sourceimpl IpTables
impl IpTables
pub fn new() -> Self
Sourcepub fn can_handle_getsockopt(level: u32, optname: u32) -> bool
pub fn can_handle_getsockopt(level: u32, optname: u32) -> bool
Returns true if the sockopt can be handled by IpTables.
Sourcepub fn can_handle_setsockopt(level: u32, optname: u32) -> bool
pub fn can_handle_setsockopt(level: u32, optname: u32) -> bool
Returns true if the sockopt can be handled by IpTables.
pub fn getsockopt( &self, locked: &mut Locked<Unlocked>, current_task: &CurrentTask, socket: &SocketHandle, optname: u32, optval: Vec<u8>, ) -> Result<Vec<u8>, Errno>
pub fn setsockopt( &self, locked: &mut Locked<Unlocked>, current_task: &CurrentTask, socket: &SocketHandle, optname: u32, optval: SockOptValue, ) -> Result<(), Errno>