pub struct MountsWriteGuard<'a> { /* private fields */ }Expand description
A guard special cased for mount operations to defer destroying mounts until after all modifications of the global mount tree are completed.
Methods from Deref<Target = MountsWriteToken>
Sourcepub fn defer_drop<T: Send + Sync + 'static>(&self, value: T)
pub fn defer_drop<T: Send + Sync + 'static>(&self, value: T)
We cannot block while holding a MountsWriteGuard as it is a spinlock. If a Drop requires a blocking operation, use Self::defer_drop defer the blocking operation until after the MountsWriteGuard is released.