pub struct MountsWriteToken { /* private fields */ }Expand description
A proof token representing the global lock over the namespace mount topology.
Functions that take &MountsWriteToken require the caller to hold the
Kernel::mounts_lock to ensure safe modification of the global mount tree.
Implementations
Sourceimpl MountsWriteToken
impl MountsWriteToken
Sourcepub fn defer_drop<T: Send + Sync + 'static>(&self, value: T)
pub fn defer_drop<T: Send + Sync + 'static>(&self, value: T)
We cannot block while holding a MountsWriteGuard as it is a spinlock. If a Drop requires a blocking operation, use Self::defer_drop defer the blocking operation until after the MountsWriteGuard is released.