pub struct PidTable { /* private fields */ }Implementations
Sourceimpl PidTable
impl PidTable
Sourcepub fn lock(&self) -> PidTableGuard<'_>
pub fn lock(&self) -> PidTableGuard<'_>
Acquires the lock for mutations, returning a PidTableGuard.
pub fn get(&self, pid: pid_t) -> Result<Pid, Errno>
pub fn set_thread_group_notifier( &self, notifier: Sender<MemoryAttributionLifecycleEvent>, )
pub fn get_thread_groups<'a>( &'a self, scope: &'a RcuReadScope, ) -> impl Iterator<Item = Arc<ThreadGroup>> + 'a
Sourcepub fn process_ids(&self) -> Vec<pid_t> ⓘ
pub fn process_ids(&self) -> Vec<pid_t> ⓘ
Returns the process ids for all processes, including zombies.
Sourcepub fn running_task_ids<'a>(
&'a self,
scope: &'a RcuReadScope,
) -> impl Iterator<Item = &'a Pid>
pub fn running_task_ids<'a>( &'a self, scope: &'a RcuReadScope, ) -> impl Iterator<Item = &'a Pid>
Returns an iterator over the Pids for all the currently running tasks.
pub fn last_pid(&self) -> pid_t