PidTableGuard

Struct PidTableGuard 

pub struct PidTableGuard<'a> { /* private fields */ }
An RAII guard representing exclusive writer access to a PidTable.

Holding this guard serializes mutations (allocations, reservations, removals) to the PID table while allowing concurrent lock-free reads.

Implementations

Source

impl<'a> PidTableGuard<'a>

pub fn allocate_pid(&mut self) -> Result<Pid, Errno>

Allocates a new PID, returning an error if the PID table is full.

pub fn add_task(&mut self, task: Arc<Task>)

pub fn remove_task(&mut self, tid: &Pid)

pub fn kill_process(&mut self, pid: &Pid)

Replace process with the specified pid with a zombie.

pub fn remove_zombie(&mut self, pid: &Pid)

pub fn add_process_group(&mut self, process_group: &Arc<ProcessGroup>)

pub fn remove_process_group(&mut self, leader: &Pid)

Methods from Deref<Target = PidTable>

pub fn lock(&self) -> PidTableGuard<'_>

Acquires the lock for mutations, returning a PidTableGuard.

pub fn get(&self, pid: pid_t) -> Result<Pid, Errno>

pub fn set_thread_group_notifier( &self, notifier: Sender<MemoryAttributionLifecycleEvent>, )

pub fn get_thread_groups<'a>( &'a self, scope: &'a RcuReadScope, ) -> impl Iterator<Item = Arc<ThreadGroup>> + 'a

pub fn process_ids(&self) -> Vec<pid_t> ⓘ

Returns the process ids for all processes, including zombies.

pub fn running_task_ids<'a>( &'a self, scope: &'a RcuReadScope, ) -> impl Iterator<Item = &'a Pid>

Returns an iterator over the Pids for all the currently running tasks.

pub fn last_pid(&self) -> pid_t

pub fn max(&self) -> pid_t

Returns the maximal PID value allowed for allocation.

pub fn set_max(&self, max: pid_t)

Sets the maximal PID value allowed for allocation.