pub struct SeccompFilterContainer {
pub filters: Vec<Arc<SeccompFilter>>,
pub provided_instructions: u16,
}Expand description
A list of seccomp filters, intended to be associated with a specific process.
Fields
filters: Vec<Arc<SeccompFilter>>List of currently installed seccomp_filters; most recently added is last.
provided_instructions: u16Implementations
Sourceimpl SeccompFilterContainer
impl SeccompFilterContainer
Sourcepub fn can_sync_to(&self, source: &SeccompFilterContainer) -> bool
pub fn can_sync_to(&self, source: &SeccompFilterContainer) -> bool
Ensures that this set of seccomp filters can be “synced to” the given set. This means that our filters are a prefix of the given set of filters.
Sourcepub fn add_filter(
&mut self,
filter: Arc<SeccompFilter>,
original_length: u16,
) -> Result<(), Errno>
pub fn add_filter( &mut self, filter: Arc<SeccompFilter>, original_length: u16, ) -> Result<(), Errno>
Adds the given filter to this list. The original_length parameter is the length of the originally provided BPF (i.e., the number of sock_filter instructions), used to ensure the total length does not exceed SECCOMP_MAX_INSNS_PER_PATH
Sourcepub fn run_all(
&self,
current_task: &CurrentTask,
syscall: &Syscall,
) -> SeccompFilterResult
pub fn run_all( &self, current_task: &CurrentTask, syscall: &Syscall, ) -> SeccompFilterResult
Runs all of the seccomp filters in this container, most-to-least recent. Returns the highest priority result (which contains a reference to the filter that generated it)
pub fn create_notifier() -> SeccompNotifierHandle
pub fn register_listener( current_task: &CurrentTask, notifier: SeccompNotifierHandle, ) -> Result<FdNumber, Errno>