pub struct Session {
pub leader: pid_t,
pub mutable_state: LockDepRwLock<SessionMutableState, SessionMutableStateLock>,
}Expand description
A session is a collection of ProcessGroup objects that are related to each other. Each
session has a session ID (sid), which is a unique identifier for the session.
The session leader is the first ProcessGroup in a session. It is responsible for managing the
session, including sending signals to all processes in the session and controlling the
foreground and background process groups.
When a ProcessGroup is created, it is automatically added to the session of its parent.
See setsid(2) for information about creating sessions.
A session can be destroyed when the session leader exits or when all process groups in the session are destroyed.
Fields
leader: pid_tThe leader of the session
mutable_state: LockDepRwLock<SessionMutableState, SessionMutableStateLock>The mutable state of the Session.
Implementations
Sourceimpl Session
impl Session
pub fn new(leader: pid_t) -> Arc<Session> ⓘ
Sourcepub fn disassociate_controlling_terminal<L>(&self, locked: &mut Locked<L>)where
L: LockBefore<ProcessGroupState>,
pub fn disassociate_controlling_terminal<L>(&self, locked: &mut Locked<L>)where
L: LockBefore<ProcessGroupState>,
Disassociates the controlling terminal from the session.
pub fn read(&self) -> impl Deref<Target = SessionMutableState>
pub fn write(&self) -> impl DerefMut<Target = SessionMutableState>