pub struct TaskPersistentInfoState {
pub tid: Pid,
pub pid: Pid,
/* private fields */
}Expand description
The information of the task that needs to be available to the ThreadGroup while computing
which process a wait can target. It is necessary to shared this data with the ThreadGroup so
that it is available while the task is being dropped and so is not accessible from a weak
pointer.
Fields
tid: PidImmutable information about the task
pid: PidImplementations
Sourceimpl TaskPersistentInfoState
impl TaskPersistentInfoState
pub fn command_guard(&self) -> LockDepGuard<'_, TaskCommand>
Sourcepub fn real_creds(&self) -> RcuReadGuard<Credentials>
pub fn real_creds(&self) -> RcuReadGuard<Credentials>
Snapshots the credentials, returning a short-lived RCU-guarded reference.
Sourcepub fn clone_creds(&self) -> Arc<Credentials> ⓘ
pub fn clone_creds(&self) -> Arc<Credentials> ⓘ
Snapshots the credentials, returning a new reference. Use this if you need to stash the credentials somewhere.
Sourcepub fn lock_creds(&self) -> CredentialsReadGuard<'_>
pub fn lock_creds(&self) -> CredentialsReadGuard<'_>
Returns a read lock on the credentials. This is appropriate if you need to guarantee that the Task’s credentials will not change during a security-sensitive operation.