pub struct TaskRunningState {
pub thread: OnceLock<ZirconThread>,
pub files: LockDepMutex<Option<SharedFdTable>, TaskFilesLock>,
pub mm: RcuOptionArc<MemoryManager>,
pub fs: RcuArc<FsContext>,
pub abstract_socket_namespace: Arc<AbstractUnixSocketNamespace>,
pub abstract_vsock_namespace: Arc<AbstractVsockSocketNamespace>,
pub proc_pid_directory_cache: RcuOptionBox<FsNodeHandle>,
}Expand description
The running state of a task.
This structure contains the state of a task that is only relevant while the task is running. It is dropped when the task enters an exited state.
Fields
thread: OnceLock<ZirconThread>A handle to the underlying Zircon thread object.
Some tasks lack an underlying Zircon thread. These tasks are used internally by the
Starnix kernel to track background work, typically on a kthread.
files: LockDepMutex<Option<SharedFdTable>, TaskFilesLock>The file descriptor table for this task.
This table can be shared by many tasks.
This is always Some while the task is running. It becomes None upon exit.
mm: RcuOptionArc<MemoryManager>The memory manager for this task. This is None only for system tasks.
fs: RcuArc<FsContext>The file system for this task.
abstract_socket_namespace: Arc<AbstractUnixSocketNamespace>The namespace for abstract AF_UNIX sockets for this task.
abstract_vsock_namespace: Arc<AbstractVsockSocketNamespace>The namespace for AF_VSOCK for this task.
proc_pid_directory_cache: RcuOptionBox<FsNodeHandle>The pid directory, so it doesn’t have to be generated and thrown away on every access. See https://fxbug.dev/291962828 for details.
Implementations
Sourceimpl TaskRunningState
impl TaskRunningState
pub fn files(&self) -> Result<Arc<FdTable>, Errno>
pub fn fork_files(&self) -> Option<SharedFdTable>
Unshares the file descriptor table for this task, if shared.
Updates the Arc<FdTable> reference in both SharedFdTable and CurrentTask.
pub fn mm(&self) -> Result<Arc<MemoryManager>, Errno>
pub fn fs(&self) -> Arc<FsContext> ⓘ