pub struct ThreadLockupDetector;Implementations
Sourceimpl ThreadLockupDetector
impl ThreadLockupDetector
Sourcepub fn get_long_running_threads(
threshold: MonotonicDuration,
) -> Vec<ThreadLockupInfo>
pub fn get_long_running_threads( threshold: MonotonicDuration, ) -> Vec<ThreadLockupInfo>
Iterates over the registry, finds threads that have been running longer than the threshold,
and returns their ThreadLockupInfo.
Sourcepub fn track() -> LockupDetectorGuard
pub fn track() -> LockupDetectorGuard
Starts tracking the current operation on the current thread. Returns a guard that stops tracking when dropped.
Sourcepub fn pause_tracking() -> LockupDetectorWaitingGuard
pub fn pause_tracking() -> LockupDetectorWaitingGuard
Pauses tracking for the current operation on the current thread. Returns a guard that resumes tracking when dropped.
Sourcepub fn track_future<F>(inner: F) -> LockupDetectorFuture<F> ⓘ
pub fn track_future<F>(inner: F) -> LockupDetectorFuture<F> ⓘ
Wraps a future to track its execution when polled.
Sourcepub fn tracked_channel<T>() -> (Sender<T>, LockupDetectorReceiver<T>)
pub fn tracked_channel<T>() -> (Sender<T>, LockupDetectorReceiver<T>)
Creates a channel where the receiver pauses tracking while waiting for messages.
pub fn active_rcu_read_locks<F>(check: F)