ZirconProcess

Struct ZirconProcess 

pub struct ZirconProcess { /* private fields */ }

Implementations

Source

impl ZirconProcess

pub fn new(process: Process) -> Self

pub fn koid(&self) -> Result<Koid, Status>

Methods from Deref<Target = Process>

pub fn raw_handle(&self) -> u32

Return the handle’s integer value.

pub fn is_invalid(&self) -> bool

pub fn unowned(&self) -> Unowned<'_, Process>

Returns an [Unowned] referring to this handle.

pub fn as_handle_ref(&self) -> Unowned<'_, NullableHandle>

Returns a [HandleRef] referring to this handle.

pub fn duplicate_handle(&self, rights: Rights) -> Result<Process, Status>

Wraps the zx_handle_duplicate syscall.

pub fn signal( &self, clear_mask: Signals, set_mask: Signals, ) -> Result<(), Status>

Wraps the zx_object_signal syscall.

pub fn wait_one( &self, signals: Signals, deadline: Instant<MonotonicTimeline>, ) -> WaitResult

Wraps the zx_object_wait_one syscall.

pub fn wait_async( &self, port: &Port, key: u64, signals: Signals, options: WaitAsyncOpts, ) -> Result<(), Status>

Wraps the zx_object_wait_async syscall.

pub fn wait_item(&self, signals: Signals) -> WaitItem<'_>

Return a WaitItem for this handle and the provided signals to use with object_wait_many.

pub fn get_name(&self) -> Result<Name, Status>

Wraps a call to the zx_object_get_property syscall for the ZX_PROP_NAME property.

pub fn set_name(&self, name: &Name) -> Result<(), Status>

Wraps a call to the zx_object_set_property syscall for the ZX_PROP_NAME property.

pub fn basic_info(&self) -> Result<HandleBasicInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_HANDLE_BASIC topic.

pub fn count_info(&self) -> Result<HandleCountInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_HANDLE_COUNT topic.

pub fn koid(&self) -> Result<Koid, Status>

Returns the Koid for the object referred to by this handle.

pub fn get_debug_addr(&self) -> Result<u64, Status>

pub fn set_debug_addr(&self, val: &u64) -> Result<(), Status>

pub fn get_break_on_load(&self) -> Result<u64, Status>

pub fn set_break_on_load(&self, val: &u64) -> Result<(), Status>

pub fn start( &self, thread: &Thread, entry: usize, stack: usize, arg1: NullableHandle, arg2: usize, ) -> Result<(), Status>

Similar to Thread::start, but is used to start the first thread in a process.

Wraps the zx_process_start syscall.

pub fn create_thread(&self, name: &[u8]) -> Result<Thread, Status>

Create a thread inside a process.

Wraps the zx_thread_create syscall.

pub fn write_memory(&self, vaddr: usize, bytes: &[u8]) -> Result<usize, Status>

Write memory inside a process.

Wraps the zx_process_write_memory syscall.

pub fn read_memory( &self, vaddr: usize, bytes: &mut [u8], ) -> Result<usize, Status>

Read memory from inside a process.

Wraps the zx_process_read_memory syscall.

pub fn read_memory_uninit<'a>( &self, vaddr: usize, buffer: &'a mut [MaybeUninit<u8>], ) -> Result<(&'a mut [u8], &'a mut [MaybeUninit<u8>]), Status>

Read memory from inside a process without requiring the output buffer to be initialized.

Wraps the zx_process_read_memory syscall.

pub fn info(&self) -> Result<ProcessInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_PROCESS topic.

pub fn threads(&self) -> Result<Vec<Koid>, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_PROCESS_THREADS topic.

pub fn task_stats(&self) -> Result<TaskStatsInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_TASK_STATS topic.

pub fn info_maps_vec(&self) -> Result<Vec<MapInfo>, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_PROCESS_MAPS topic.

pub fn handle_stats(&self) -> Result<ProcessHandleStats, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_PROCESS_HANDLE_STATS topic.

pub fn get_child(&self, koid: &Koid, rights: Rights) -> Result<Thread, Status>

Wraps the zx_object_get_child syscall.

pub fn info_vmos_vec(&self) -> Result<Vec<VmoInfo>, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_PROCESS_VMO topic.

pub fn info_maps<'a>( &self, info_out: &'a mut [MaybeUninit<MapInfo>], ) -> Result<(&'a mut [MapInfo], &'a mut [MaybeUninit<MapInfo>], usize), Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_PROCESS_MAPS topic. Contrarily to Process::info_vmos_vec, this method ensures that no intermediate copy of the data is made, at the price of a less convenient interface.

pub fn info_vmos<'a>( &self, info_out: &'a mut [MaybeUninit<VmoInfo>], ) -> Result<(&'a mut [VmoInfo], &'a mut [MaybeUninit<VmoInfo>], usize), Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_PROCESS_VMO topic. Contrarily to Process::info_vmos_vec, this method ensures that no intermediate copy of the data is made, at the price of a less convenient interface.