pub struct PortWaitCanceler { /* private fields */ }Expand description
Return values for wait_async methods that monitor the state of a handle.
Calling cancel will cancel any running wait.
Does not implement Clone or Copy so that only a single canceler exists
per wait.
Implementations