pub fn anon_test_file(
current_task: &CurrentTask,
ops: Box<dyn FileOps>,
flags: OpenFlags,
) -> FileHandleExpand description
Returns a new anonymous test file with the specified ops and flags.
pub fn anon_test_file(
current_task: &CurrentTask,
ops: Box<dyn FileOps>,
flags: OpenFlags,
) -> FileHandleReturns a new anonymous test file with the specified ops and flags.