pub fn spawn_kernel_and_run<F, R>(callback: F) -> impl Future<Output = R>Expand description
Create a Kernel object and run the given callback in the init process for that kernel.
This function is useful if you want to test code that requires a CurrentTask because your callback is called with the init process as the CurrentTask.