UtcClock

Struct UtcClock 

pub struct UtcClock { /* private fields */ }

Implementations

Source

impl UtcClock

pub fn new(real_utc_clock: UtcClockHandle) -> Self

Creates a new UtcClock instance.

The real_utc_clock is a handle to an underlying Fuchsia UTC clock. It will be used once started.

pub fn now(&self) -> UtcInstant

Returns the current Starnix UTC time.

In Starnix, UTC time is always running. It is started from backstop at Starnix boot, and adjusted to actual UTC once Fuchsia UTC clock is started.

pub fn estimate_boot_time(&self, utc: UtcInstant) -> (BootInstant, bool)

Estimates the boot time corresponding to utc.

Returns
  • zx::BootInstant: estimated boot time;
  • bool: true if the system UTC clock has been started.

Takes about 900ns worst case.