pub enum DirectoryMode {
AllowAny,
MustBeDirectory,
}Expand description
The DirectoryMode enum encodes whether a lookup requires the target to be a directory.
Variants
AllowAny
The target of the path resolution can be any file type.
MustBeDirectory
The target of the path resolution must be a directory.