pub enum FsLockDepType {
Normal,
Recursive,
Fuse,
}Expand description
The type of the filesystem for LockDep purposes.
Normal filesystems use standard lock levels.
Recursive filesystems (like OverlayFS) use lock levels that precede normal ones,
allowing them to lock the underlying filesystem without violating the hierarchy.
Fuse filesystems do blocking calls while holding locks and require specific lock
ordering because of this.
Variants