pub struct PipeFileObject { /* private fields */ }Implementations
Sourceimpl PipeFileObject
impl PipeFileObject
Sourcepub fn splice_from(
&self,
current_task: &CurrentTask,
self_file: &FileHandle,
from: &FileHandle,
maybe_offset: Option<usize>,
len: usize,
non_blocking: bool,
) -> Result<usize, Errno>
pub fn splice_from( &self, current_task: &CurrentTask, self_file: &FileHandle, from: &FileHandle, maybe_offset: Option<usize>, len: usize, non_blocking: bool, ) -> Result<usize, Errno>
Splice from the given file handle to this pipe.
The given file handle must not be a pipe. If you wish to splice between two pipes, use
lock_pipes and Pipe::splice.
Sourcepub fn splice_to(
&self,
current_task: &CurrentTask,
self_file: &FileHandle,
to: &FileHandle,
maybe_offset: Option<usize>,
len: usize,
non_blocking: bool,
) -> Result<usize, Errno>
pub fn splice_to( &self, current_task: &CurrentTask, self_file: &FileHandle, to: &FileHandle, maybe_offset: Option<usize>, len: usize, non_blocking: bool, ) -> Result<usize, Errno>
Splice from this pipe to the given file handle.
The given file handle must not be a pipe. If you wish to splice between two pipes, use
lock_pipes and Pipe::splice.
Sourcepub fn vmsplice_from(
&self,
current_task: &CurrentTask,
self_file: &FileHandle,
iovec: UserBuffers,
non_blocking: bool,
) -> Result<usize, Errno>
pub fn vmsplice_from( &self, current_task: &CurrentTask, self_file: &FileHandle, iovec: UserBuffers, non_blocking: bool, ) -> Result<usize, Errno>
Share the mappings backing the given input buffer into the pipe.
Returns the number of bytes enqueued.
Sourcepub fn vmsplice_to(
&self,
current_task: &CurrentTask,
self_file: &FileHandle,
iovec: UserBuffers,
non_blocking: bool,
) -> Result<usize, Errno>
pub fn vmsplice_to( &self, current_task: &CurrentTask, self_file: &FileHandle, iovec: UserBuffers, non_blocking: bool, ) -> Result<usize, Errno>
Copy data from the pipe to the given output buffer.
Returns the number of bytes transferred.
Sourcepub fn lock_pipes<'a, 'b>(
current_task: &CurrentTask,
file_in: &'a FileHandle,
file_out: &'b FileHandle,
len: usize,
non_blocking: bool,
) -> Result<PipeOperands<'a, 'b>, Errno>
pub fn lock_pipes<'a, 'b>( current_task: &CurrentTask, file_in: &'a FileHandle, file_out: &'b FileHandle, len: usize, non_blocking: bool, ) -> Result<PipeOperands<'a, 'b>, Errno>
Obtain the pipe objects from the given file handles, if they are both pipes.
Returns EINVAL if one (or both) of the given file handles is not a pipe.
Obtains the locks on the pipes in the correct order to avoid deadlocks.