pub struct FileSystemOptions {
pub source: FlyByteStr,
pub flags: AtomicFileSystemFlags,
pub params: MountParams,
}Fields
source: FlyByteStrThe source string passed as the first argument to mount(), e.g. a block device.
flags: AtomicFileSystemFlagsFlags kept per-superblock.
params: MountParamsFilesystem options passed as the last argument to mount().
Implementations
Sourceimpl FileSystemOptions
impl FileSystemOptions
pub fn source_for_display(&self) -> &FsStr