pub struct MemoryRegularNode { /* private fields */ }Implementations
Sourceimpl MemoryRegularNode
impl MemoryRegularNode
Sourcepub fn from_memory(memory: Arc<MemoryObject>) -> Self
pub fn from_memory(memory: Arc<MemoryObject>) -> Self
Create a new file node based on an existing VMO.
Attempts to open the file for writing will fail unless [memory] has both
the WRITE and RESIZE rights.