pub struct OpenAccessCheck { /* private fields */ }Expand description
Configuration for opening a file, bundling open flags with concrete permission checks.
Implementations
Sourceimpl OpenAccessCheck
impl OpenAccessCheck
Sourcepub fn new(open_flags: OpenFlags, access_check: AccessCheck) -> Self
pub fn new(open_flags: OpenFlags, access_check: AccessCheck) -> Self
Creates an open check with explicit open flags and access check.
Sourcepub fn skip(open_flags: OpenFlags) -> Self
pub fn skip(open_flags: OpenFlags) -> Self
Skips permission checks when opening a file with the specified flags.
Sourcepub fn for_exec() -> Self
pub fn for_exec() -> Self
Configures read-only flags with an execute permission check for execve(2) / execveat(2).
Sourcepub fn open_flags(&self) -> OpenFlags
pub fn open_flags(&self) -> OpenFlags
Open flags for the file.
Sourcepub fn access_check(&self) -> AccessCheck
pub fn access_check(&self) -> AccessCheck
Permission checks to perform when opening the file.