SharedFdTable

Struct SharedFdTable 

pub struct SharedFdTable {
    pub table: Arc<FdTable>,
}
A wrapper around FdTable that manages the table’s logical share count.

This type represents the primary reference to the file descriptor table held by a task. Cloning and dropping SharedFdTable increment and decrement the share count of the FdTable, respectively. When the last SharedFdTable for the table is dropped, the table is cleared.

Fields

table: Arc<FdTable>

Implementations

Source

impl SharedFdTable

pub fn new(table: Arc<FdTable>) -> Self

pub fn unshare(&mut self)

Replaces the wrapped table with a fork that has an independent share count.

Methods from Deref<Target = FdTable>

pub fn id(&self) -> FdTableId

Returns the FdTableId of the FdTable.

pub fn fork(&self) -> Arc<Self>

Returns new unshared FdTable that is a snapshot of the state of the FdTable.

pub fn exec(&self)

Trims close-on-exec file descriptors from the table.

pub fn insert( &self, current_task: &CurrentTask, fd: FdNumber, file: FileHandle, ) -> Result<(), Errno>

Inserts a file descriptor into the table.

pub fn add( &self, current_task: &CurrentTask, file: FileHandle, flags: FdFlags, ) -> Result<FdNumber, Errno>

Adds a file descriptor to the table.

The file descriptor will be assigned the next available number.

Returns the assigned file descriptor number.

This function is the most common way to add a file descriptor to the table.

pub fn duplicate( &self, current_task: &CurrentTask, oldfd: FdNumber, target: TargetFdNumber, flags: FdFlags, ) -> Result<FdNumber, Errno>

Duplicates a file descriptor.

If target is TargetFdNumber::Minimum, a new FdNumber is allocated. Returns the new FdNumber.

pub fn get_allowing_opath(&self, fd: FdNumber) -> Result<FileHandle, Errno>

Returns the file handle associated with the given file descriptor.

Returns the file handle even if the file was opened with O_PATH.

This operation is uncommon. Most clients should use get instead, which fails if the file was opened with O_PATH.

pub fn get_allowing_opath_with_flags( &self, fd: FdNumber, ) -> Result<(FileHandle, FdFlags), Errno>

Returns the file handle and flags associated with the given file descriptor.

Returns the file handle even if the file was opened with O_PATH.

This operation is uncommon. Most clients should use get instead, which fails if the file was opened with O_PATH.

pub fn get(&self, fd: FdNumber) -> Result<FileHandle, Errno>

Returns the file handle associated with the given file descriptor.

This operation fails if the file was opened with O_PATH.

pub fn close(&self, fd: FdNumber) -> Result<(), Errno>

Closes the file descriptor associated with the given file descriptor.

This operation fails if the file descriptor is not valid.

pub fn get_fd_flags_allowing_opath( &self, fd: FdNumber, ) -> Result<FdFlags, Errno>

Returns the flags associated with the given file descriptor.

Returns the flags even if the file was opened with O_PATH.

pub fn ioctl_fd_flags( &self, current_task: &CurrentTask, fd: FdNumber, request: u32, ) -> Result<(), Errno>

Updates the flags of the specified FD with the requested change.

This operation fails if the file descriptor was opened with O_PATH or is not valid.

pub fn set_fd_flags_allowing_opath( &self, fd: FdNumber, flags: FdFlags, ) -> Result<(), Errno>

Sets the flags associated with the given file descriptor.

This operation fails if the file descriptor is not valid.

pub fn retain<F>(&self, predicate: F)
where F: Fn(FdNumber, &mut FdFlags) -> bool,

Retains only the FDs matching the given predicate.

The predicate is called with the FdNumber and a mutable reference to the FdFlags for each entry in the FdTable. If the predicate returns false, the entry is removed from the FdTable. Otherwise, the FdFlags are updated to the value modified by the predicate.

pub fn get_all_fds(&self) -> Vec<FdNumber>

Returns a vector of all current file descriptors in the table.

pub fn remap<F: Fn(&FileHandle) -> Option<FileHandle>>( &self, _current_task: &CurrentTask, predicate: F, )

Executes predicate(file) => maybe_replacement on every non-empty table entry.

Replaces file with replacement_file in the table when maybe_replacement == Some(replacement_file).

pub fn read<'a>(self: &'a FdTable) -> FdTableReadGuard<'a>

pub fn write<'a>(self: &'a FdTable) -> FdTableWriteGuard<'a>