CloseFreeSafe

Trait CloseFreeSafe 

pub trait CloseFreeSafe { }
Marker trait for implementation of FileOps that do not need to implement close and can then pass a wrapper object as the FileOps implementation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl CloseFreeSafe for SimpleDirectory

SimpleDirectory doesn’t implement the close method.