FutexTable

Struct FutexTable 

pub struct FutexTable<Key: FutexKey> { /* private fields */ }
A table of futexes.

Each 32-bit aligned address in an address space can potentially have an associated futex that userspace can wait upon. This table is a sparse representation that has an actual WaitQueue only for those addresses that have ever actually had a futex operation performed on them.

Implementations

Source

impl<Key: FutexKey> FutexTable<Key>

pub fn wait_boot( &self, locked: &mut Locked<Unlocked>, current_task: &CurrentTask, addr: UserAddress, value: u32, mask: u32, deadline: BootInstant, timer_slack: BootDuration, ) -> Result<(), Errno>

Wait on the futex at the given address given a boot deadline.

See FUTEX_WAIT when passed a deadline in CLOCK_REALTIME.

pub fn wait<L>( &self, locked: &mut Locked<L>, current_task: &CurrentTask, addr: UserAddress, value: u32, mask: u32, deadline: MonotonicInstant, ) -> Result<(), Errno>

Wait on the futex at the given address.

See FUTEX_WAIT.

pub fn wake<L>( &self, locked: &mut Locked<L>, task: &Task, addr: UserAddress, count: usize, mask: u32, ) -> Result<usize, Errno>

Wake the given number of waiters on futex at the given address. Returns the number of waiters actually woken.

See FUTEX_WAKE.

pub fn requeue<L>( &self, locked: &mut Locked<L>, current_task: &CurrentTask, addr: UserAddress, wake_count: usize, requeue_count: usize, new_addr: UserAddress, expected_value: Option<u32>, ) -> Result<usize, Errno>

Requeue the waiters to another address.

See FUTEX_CMP_REQUEUE

pub fn lock_pi<L>( &self, locked: &mut Locked<L>, current_task: &CurrentTask, addr: UserAddress, deadline: MonotonicInstant, ) -> Result<(), Errno>

Lock the futex at the given address.

See FUTEX_LOCK_PI.

pub fn unlock_pi<L>( &self, locked: &mut Locked<L>, current_task: &CurrentTask, addr: UserAddress, ) -> Result<(), Errno>

Unlock the futex at the given address.

See FUTEX_UNLOCK_PI.

Source

impl FutexTable<SharedFutexKey>

pub fn external_wait<L>( &self, locked: &mut Locked<L>, memory: MemoryObject, offset: u64, value: u32, mask: u32, ) -> Result<(Arc<()>, Receiver<()>), Errno>

Wait on the futex at the given offset in the memory.

Returns a receiver that will be signaled when the futex is woken, and an Arc<()> token that must be kept alive by the caller for the duration of the wait. If the caller drops the token (e.g., if the external client disconnects), the waiter is marked as stale and will be garbage-collected by the next futex operation on this table.

See FUTEX_WAIT.

pub fn external_wake<L>( &self, locked: &mut Locked<L>, memory: MemoryObject, offset: u64, count: usize, mask: u32, ) -> Result<usize, Errno>

Wake the given number of waiters on futex at the given offset in the memory. Returns the number of waiters actually woken.

See FUTEX_WAKE.