pub struct MappingContext {
pub user_vmar: Vmar,
pub user_vmar_info: VmarInfo,
pub private_anonymous: PrivateAnonymousMemoryManager,
}Expand description
State and resources of the MemoryManager that are either immutable after creation
or handle their own interior mutability (e.g., private_anonymous).
This is distinct from MemoryManagerState in that the fields here do not require
acquisition of the MemoryManager’s main lock for access. This allows concurrent
access to these resources without lock contention.
This structure primarily holds the Zircon VMAR handle and the manager for private anonymous memory, which are the core primitives used to manipulate the address space.
Fields
user_vmar: VmarThe VMAR in which userspace mappings occur.
We map userspace memory in this child VMAR so that we can destroy the entire VMAR during exec. For 32-bit tasks, we limit the user_vmar to correspond to the available memory.
This field is set to ZX_HANDLE_INVALID when the address-space has been destroyed (e.g. on
exec()), allowing the value to be pro-actively checked for, or the ZX_ERR_BAD_HANDLE
status return from Zircon operations handled, to suit the call-site.
user_vmar_info: VmarInfoCached VmarInfo for user_vmar.
private_anonymous: PrivateAnonymousMemoryManagerMemory object backing private, anonymous memory allocations in this address space.
Implementations
Sourceimpl MappingContext
impl MappingContext
pub fn max_address(&self) -> UserAddress