pub trait OnWakeOps: Send + Sync {
// Required method
fn on_wake(&self, current_task: &CurrentTask, baton_lease: &NullableHandle);
}Expand description
Called when a wake happens resulting from a timer going off.
Required Methods
Sourcefn on_wake(&self, current_task: &CurrentTask, baton_lease: &NullableHandle)
fn on_wake(&self, current_task: &CurrentTask, baton_lease: &NullableHandle)
Called on wake events.
Must not block.
Args
current_task: the currently active taskbaton_lease: the wake lease is provided ifon_wakehas critical work to do and needs to prevent suspend.