pub fn bprm_committing_creds(
locked: &mut Locked<Unlocked>,
current_task: &CurrentTask,
elf_state: &ResolvedElf,
) -> Result<(), Errno>Expand description
Called during exec(), immediately before the elf_state.creds are applied to the calling
process. This is typically used to apply restrictions on the calling process, such as closing
file descriptors to which the new security domain will not have access.
Corresponds to the bprm_committing_creds() LSM hook.