pub trait ClosureKind { }Expand description
Denotes whether a closure has been provided. A request can not be built at all without a closure.
See SpawnRequestBuilder for usage details.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl ClosureKind for ClosureNone
impl<T: Send + 'static, FN: FnOnce(&CurrentTask) -> T + Send + 'static> ClosureKind for FN
A builder type state where a closure has been provided. See SpawnRequestBuilder for usage details.