pub struct Idr<T: RcuDroppable + Send + Sync + 'static, L: LockLevel> { /* private fields */ }Expand description
A concurrent, lock-free radix tree mapped structure primarily employed to map 32-bit IDs to objects. Optimized for massively contended reads.
Implementations
Sourceimpl<T: RcuDroppable + Send + Sync + 'static, L: LockLevel> Idr<T, L>
impl<T: RcuDroppable + Send + Sync + 'static, L: LockLevel> Idr<T, L>
Sourcepub fn new(alloc_mode: IdrAllocMode) -> Self
pub fn new(alloc_mode: IdrAllocMode) -> Self
Creates a new Idr radix tree with the specified allocation mode.
Sourcepub fn new_cyclic(min_after_wrap: Option<u32>) -> Self
pub fn new_cyclic(min_after_wrap: Option<u32>) -> Self
Creates a new cyclic Idr radix tree with an optional minimum ID after wrapping.
Sourcepub fn lock(&self) -> IdrGuard<'_, T, L>
pub fn lock(&self) -> IdrGuard<'_, T, L>
Acquires the writer lock, returning an IdrGuard that provides mutating operations.
Sourcepub fn lookup(&self, id: u32, scope: &RcuReadScope) -> Option<Arc<T>>
pub fn lookup(&self, id: u32, scope: &RcuReadScope) -> Option<Arc<T>>
RCU protected lock-free lookup for readers
Sourcepub fn iter<'a>(&'a self, scope: &'a RcuReadScope) -> IdrIterator<'a, T> ⓘ
pub fn iter<'a>(&'a self, scope: &'a RcuReadScope) -> IdrIterator<'a, T> ⓘ
Returns a lock-free RCU iterator over all entries