pub struct IdrGuard<'a, T: RcuDroppable + Send + Sync + 'static, L: LockLevel> { /* private fields */ }Expand description
An RAII guard representing exclusive writer access to an Idr.
Holding this guard serializes mutations (allocations, reservations, removals) to the radix tree while allowing concurrent lock-free reads.
Implementations
Sourceimpl<'a, T: RcuDroppable + Send + Sync + 'static, L: LockLevel> IdrGuard<'a, T, L>
impl<'a, T: RcuDroppable + Send + Sync + 'static, L: LockLevel> IdrGuard<'a, T, L>
Sourcepub fn alloc<F>(&mut self, factory: F) -> Option<(u32, Arc<T>)>
pub fn alloc<F>(&mut self, factory: F) -> Option<(u32, Arc<T>)>
Allocates the next available ID by calling a factory providing the newly acquired ID.
Depending on the Idr configuration, allocation will be either linear starting
from 0, or cyclic starting from the previous cursor position.
Sourcepub fn reserve_id(&mut self, id: u32)
pub fn reserve_id(&mut self, id: u32)
Marks a specific ID as unavailable so the allocator will never return it. Does not populate the tree with an item.
Methods from Deref<Target = Idr<T, L>>
Sourcepub fn lock(&self) -> IdrGuard<'_, T, L>
pub fn lock(&self) -> IdrGuard<'_, T, L>
Acquires the writer lock, returning an IdrGuard that provides mutating operations.
Sourcepub fn lookup(&self, id: u32, scope: &RcuReadScope) -> Option<Arc<T>>
pub fn lookup(&self, id: u32, scope: &RcuReadScope) -> Option<Arc<T>>
RCU protected lock-free lookup for readers
Sourcepub fn iter<'a>(&'a self, scope: &'a RcuReadScope) -> IdrIterator<'a, T> ⓘ
pub fn iter<'a>(&'a self, scope: &'a RcuReadScope) -> IdrIterator<'a, T> ⓘ
Returns a lock-free RCU iterator over all entries