pub struct MountsWriteToken(/* private fields */);Expand description
A proof token representing the global lock over the namespace mount topology.
Functions that take &MountsWriteToken require the caller to hold the
Kernel::mounts_lock to ensure safe modification of the global mount tree.