pub struct SessionDisassociation { /* private fields */ }Expand description
Represents the disassociation of a session’s controlling terminal when the session leader exits.
This struct wraps an optional session and ensures that disassociate_controlling_terminal
is explicitly called by the caller, which must be done without holding any
ThreadGroup’s write lock.
Implementations
Sourceimpl SessionDisassociation
impl SessionDisassociation
Sourcepub fn disassociate_controlling_terminal<L>(self, locked: &mut Locked<L>)where
L: LockBefore<ProcessGroupState>,
pub fn disassociate_controlling_terminal<L>(self, locked: &mut Locked<L>)where
L: LockBefore<ProcessGroupState>,
Disassociates the controlling terminal from the session.
If the exiting thread group is the session leader, the controlling terminal must be disassociated. This must be called after dropping the ThreadGroup write lock to prevent a lock order violation.
Calling it after the thread group has left the process group also ensures that the exiting thread group is no longer in the process group when attempting to send SIGHUP/SIGCONT to the foreground process group, avoiding a self-deadlock where the exiting thread group attempts to write-lock itself.