pub struct TaskLiveState {
pub thread: RwLock<Option<Arc<Thread>>>,
pub files: FdTable,
pub mm: RcuOptionArc<MemoryManager>,
pub fs: RcuArc<FsContext>,
pub abstract_socket_namespace: Arc<AbstractUnixSocketNamespace>,
pub abstract_vsock_namespace: Arc<AbstractVsockSocketNamespace>,
}Expand description
The live state of a task.
This structure contains the state of a task that is only relevant while the task is alive. It is dropped when the task enters the zombie state.
Fields
thread: RwLock<Option<Arc<Thread>>>A handle to the underlying Zircon thread object.
Some tasks lack an underlying Zircon thread. These tasks are used internally by the
Starnix kernel to track background work, typically on a kthread.
files: FdTableThe file descriptor table for this task.
This table can be share by many tasks.
mm: RcuOptionArc<MemoryManager>The memory manager for this task. This is None only for system tasks.
fs: RcuArc<FsContext>The file system for this task.
abstract_socket_namespace: Arc<AbstractUnixSocketNamespace>The namespace for abstract AF_UNIX sockets for this task.
abstract_vsock_namespace: Arc<AbstractVsockSocketNamespace>The namespace for AF_VSOCK for this task.
Implementations