pub struct ZirconThread {
pub thread: Arc<Thread>,
pub koid: Koid,
}Expand description
A synchronized container for a Zircon thread and its cached KOID.
Fields
thread: Arc<Thread>The underlying Zircon thread.
Thread Safety
Blocking operations are unsafe while holding RCU read locks. However, references to this
thread must be held across blocking operations (e.g., futex waits). The ZirconThread
container as a whole is guarded by RCU because it is a member of the RCU-guarded
TaskRunningState. This field is reference counted so it can be accessed outside of RCU
locks through a strong reference.
Holding a reference to the thread does not guarantee that the task to which it belongs will
continue running. The task may exit at any time. The thread will continue to exist in memory
until all references are dropped. When the task exits and execution stops, reference holders
will observe the thread transition to zx::ThreadState::Dead normally.
koid: KoidImplementations