pub trait ZombieReleaser {
// Required method
fn remove_zombie(&mut self, pid: &Pid);
}Expand description
Trait for releasing a zombie process from the PID table.
This trait erases the lifetime parameter of PidTableGuard so that ZombieProcess can
implement Releasable without tying the mutable reference lifetime to the guard’s lifetime
parameter, preserving variance and allowing reborrowing in loops and across sequential calls.
Required Methods
fn remove_zombie(&mut self, pid: &Pid)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".