pub struct RenameContext<'a> {
pub renamed: &'a DirEntryHandle,
pub replaced: Option<&'a DirEntryHandle>,
/* private fields */
}Expand description
A context that holds the locked children and info of the parents during a rename operation.
The context is constructed by locking the parent directories
(old_parent, new_parent) for write. These parent locks are held for
the duration of the context’s lifetime, preventing concurrent
modifications to the parents.
Child nodes (renamed and replaced) are not locked upon
construction. To query properties of the children (like whether they are
directories) without risking deadlocks, use the provided helper methods
(renamed_is_dir, replaced_is_dir) instead of locking them directly.
Fields
renamed: &'a DirEntryHandlereplaced: Option<&'a DirEntryHandle>Implementations
Sourceimpl<'a> RenameContext<'a>
impl<'a> RenameContext<'a>
Sourcepub fn renamed_is_dir(&self) -> bool
pub fn renamed_is_dir(&self) -> bool
Returns whether the renamed child node is a directory.
This method safely handles child info locking under the parent locks.
If the renamed node is same as a parent (which is already locked),
it uses the parent’s guard to avoid self-deadlock. Otherwise, it
locks the child info using allow_subclass.
Sourcepub fn replaced_is_dir(&self) -> bool
pub fn replaced_is_dir(&self) -> bool
Returns whether the replaced child node is a directory.
Returns false if replaced is None.
This method safely handles child info locking under the parent locks.
If the replaced node is same as a parent (which is already locked),
it uses the parent’s guard to avoid self-deadlock. Otherwise, it
locks the child info using allow_subclass.
Sourcepub fn old_parent(&self) -> &DirEntryHandle
pub fn old_parent(&self) -> &DirEntryHandle
Returns the old parent directory entry handle.
The old parent’s child list is write-locked for the lifetime of the context.
Sourcepub fn new_parent(&self) -> &DirEntryHandle
pub fn new_parent(&self) -> &DirEntryHandle
Returns the new parent directory entry handle.
The new parent’s child list is write-locked for the lifetime of the context.
Sourcepub fn parent_infos_mut(&mut self) -> (&mut FsNodeInfo, Option<&mut FsNodeInfo>)
pub fn parent_infos_mut(&mut self) -> (&mut FsNodeInfo, Option<&mut FsNodeInfo>)
Returns mutable references to the FsNodeInfo of both parent
directories.
The references are returned as a tuple to allow them to be borrowed mutably at the same time (e.g., to update link counts in both).
If new_parent is the same as old_parent, the second element of the
tuple will be None to prevent mutable aliasing of the same guard.
Sourcepub fn old_parent_info(&self) -> &FsNodeInfo
pub fn old_parent_info(&self) -> &FsNodeInfo
Returns a shared reference to the FsNodeInfo of the old parent
directory.
Sourcepub fn new_parent_info(&self) -> Option<&FsNodeInfo>
pub fn new_parent_info(&self) -> Option<&FsNodeInfo>
Returns a shared reference to the FsNodeInfo of the new parent
directory.
Returns None if new_parent is the same as old_parent.